==> lima-swing-0.7-sources.jar: org/chorem/lima/ui/financialtransaction/BalanceColumn.java <==
package org.chorem.lima.ui.financialtransaction;

/*
 * #%L
 * Lima :: Swing
 * $Id: BalanceColumn.java 3695 2013-07-10 09:11:39Z athimel $
 * $HeadURL: http://svn.chorem.org/svn/lima/tags/lima-0.7/lima-swing/src/main/java/org/chorem/lima/ui/financialtransaction/BalanceColumn.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.FinancialTransaction;
import org.chorem.lima.ui.celleditor.BigDecimalTableCellRenderer;

import java.math.BigDecimal;

import static org.nuiton.i18n.I18n._;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class BalanceColumn extends FinancialTransactionColumn {


    public BalanceColumn(FinancialTransactionTableModel tableModel) {
        super(tableModel);
        renderer = new BigDecimalTableCellRenderer();
    }

    @Override
    public Class<?> getColumnClass() {
        return BigDecimal.class;
    }

    @Override
    public String getColumnName() {
        return _("lima.table.balance");
    }

    @Override
    public Object getValueAt(int row) {
        BigDecimal result;
        FinancialTransaction transaction = tableModel.getTransactionAt(row);
        if (row == 0 || tableModel.getEntryAt(row - 1).getFinancialTransaction() != transaction) {
            result = transaction.getAmountDebit().subtract(transaction.getAmountCredit());
        } else {
            result = BigDecimal.ZERO;
        }
        return result;
    }

    @Override
    public boolean isCellEditable(int row) {
        return false;
    }

    @Override
    public boolean setValueAt(Object value, int row) {
        return false;
    }
}

==> lima-swing-0.7.1-sources.jar: org/chorem/lima/ui/financialtransaction/BalanceColumn.java <==
package org.chorem.lima.ui.financialtransaction;

/*
 * #%L
 * Lima :: Swing
 * $Id: BalanceColumn.java 3727 2014-01-02 09:41:08Z sbavencoff $
 * $HeadURL: https://svn.chorem.org/lima/tags/lima-0.7.1/lima-swing/src/main/java/org/chorem/lima/ui/financialtransaction/BalanceColumn.java $
 * %%
 * Copyright (C) 2008 - 2013 CodeLutin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import org.chorem.lima.entity.FinancialTransaction;
import org.chorem.lima.ui.common.AbstractColumn;
import org.chorem.lima.ui.common.FinancialTransactionTableModel;

import java.math.BigDecimal;

import static org.nuiton.i18n.I18n._;

/**
 * @author Sylvain Bavencoff <bavencoff@codelutin.com>
 */
public class BalanceColumn extends AbstractColumn<FinancialTransactionTableModel> {

    public BalanceColumn() {
        super(BigDecimal.class, _("lima.table.balance"), false);
    }

    @Override
    public Object getValueAt(int row) {
        BigDecimal result;
        FinancialTransaction transaction = tableModel.getTransactionAt(row);
        if (row == 0 || tableModel.get(row - 1).getFinancialTransaction() != transaction) {
            result = transaction.getAmountDebit().subtract(transaction.getAmountCredit());
        } else {
            result = BigDecimal.ZERO;
        }
        return result;
    }
}
